//////////////////////////////////////////////////////////////         
//      $Id: utils.h,v 1.4 2000/06/11 15:18:15 toivo Exp $ 
//
// Author: Toivo Pedaste
//
#include "../config.h"
#include <string.h>
#include <klistview.h>

class KPLVItem;

KPLVItem *findGroup(QString ame, KPLVItem *search);


